This macro is used to derive the UiComp trait on a Props, which will also implement
std::fmt::Display by getting only what is before the “Props” in the struct,
HasChildren by parsing the struct and checking if a children field is present
BuildClass by also parsing the struct and checking if a attributes field is present (which is a Vec which can contain the “class” Attribute)
BuildClass also force to implement Class on your Props, which is used for styling